@@ -257,10 +257,10 @@ class Plugin(object):
             :annotation:
 
             :py:class:`str` -- :attr:`_alias_` if set or falls back to class name
-
-    .. _PEP 440: https://www.python.org/dev/peps/pep-0440/
     """
 
+    __slots__ = ()
+
     _alias_ = None
     """:py:class:`str` -- Friendly name to refer to plugin.
        Accessed through :attr:`~Plugin.name` property."""
@@ -269,7 +269,9 @@ class Plugin(object):
        Can also be a static or class method that returns a tuple ``(bool, message)``"""
     _version_ = None
     """:py:class:`str` -- Plugin version. Should adhere to `PEP 440`_.
-       Accessed through :attr:`~Plugin.version` property"""
+       Accessed through :attr:`~Plugin.version` property.
+
+       .. _PEP 440: https://www.python.org/dev/peps/pep-0440/"""
 
     @ClassProperty
     def version(cls):  # noqa: N805  # pylint: disable=no-self-argument
@@ -310,6 +312,8 @@ class Parent(object):
     in an single program, such as in libraries and frameworks.
     """
 
+    __slots__ = 'plugin_type', 'group'
+
     def __init__(self, plugin_type=None, group=None):
         self.plugin_type = plugin_type
         self.group = group
@@ -336,6 +340,10 @@ class Parent(object):
         dict_.pop('__dict__', None)
         dict_.pop('__weakref__', None)
 
+        # Clean out slot members
+        for member in dict_.get('__slots__', ()):
+            dict_.pop(member, None)
+
         # Set type
         dict_['_type_'] = self.plugin_type or cls.__name__
         dict_['_group_'] = self.group
